@@ -139,6 +139,14 @@ func TestParseSuccess(t *testing.T) {
 
 	// numberExpr
 	same(`1`)
+	same(`123.`)
+	another(`-123.`, `-123`)
+	same(`foo - 123.`)
+	same(`12.e+4`)
+	same(`12Ki`)
+	same(`1.23Gb`)
+	same(`foo - 23M`)
+	another(`-1.23Gb`, `-1.23e+09`)
 	same(`1.23`)
 	same(`0.23`)
 	same(`1.2e+45`)
@@ -149,25 +157,25 @@ func TestParseSuccess(t *testing.T) {
 	same(`-1.2e+45`)
 	same(`-1.2e-45`)
 	same(`-1.2e-45`)
-	another(`12.5E34`, `1.25e+35`)
+	same(`12.5E34`)
 	another(`-.2`, `-0.2`)
 	another(`-.2E-2`, `-0.002`)
 	same(`NaN`)
-	another(`nan`, `NaN`)
-	another(`NAN`, `NaN`)
-	another(`nAN`, `NaN`)
-	another(`Inf`, `+Inf`)
-	another(`INF`, `+Inf`)
-	another(`inf`, `+Inf`)
-	another(`+Inf`, `+Inf`)
-	another(`-Inf`, `-Inf`)
+	same(`nan`)
+	same(`NAN`)
+	same(`nAN`)
+	same(`Inf`)
+	same(`INF`)
+	same(`inf`)
+	another(`+Inf`, `Inf`)
+	same(`-Inf`)
 	another(`-inF`, `-Inf`)
-	another(`0x12`, `18`)
-	another(`0x3b`, `59`)
+	same(`0x12`)
+	same(`0x3b`)
 	another(`-0x3b`, `-59`)
-	another(`+0X3B`, `59`)
-	another(`0b1011`, `11`)
-	another(`073`, `59`)
+	another(`+0X3B`, `0X3B`)
+	same(`0b1011`)
+	same(`073`)
 	another(`-0o12`, `-10`)
 
 	// durationExpr
@@ -581,12 +589,10 @@ func TestParseError(t *testing.T) {
 	f(`keep_metric_names "foo"`)
 
 	// invalid numberExpr
-	f(`12.`)
 	f(`1.2e`)
 	f(`23e-`)
 	f(`23E+`)
 	f(`.`)
-	f(`-12.`)
 	f(`-1.2e`)
 	f(`-23e-`)
 	f(`-23E+`)
@@ -601,7 +607,6 @@ func TestParseError(t *testing.T) {
 	// invalid binaryOpExpr
 	f(`+`)
 	f(`1 +`)
-	f(`1 + 2.`)
 	f(`3 unless`)
 	f(`23 + on (foo)`)
 	f(`m + on (,) m`)
