@@ -73,9 +73,13 @@ var transformFuncs = map[string]bool{
 	"range_avg":                  true,
 	"range_first":                true,
 	"range_last":                 true,
+	"range_linear_regression":    true,
 	"range_max":                  true,
 	"range_min":                  true,
+	"range_normalize":            true,
 	"range_quantile":             true,
+	"range_stddev":               true,
+	"range_stdvar":               true,
 	"range_sum":                  true,
 	"remove_resets":              true,
 	"round":                      true,
